SimpleOverlayLocalizations class

Localizations for simple_logger_overlay.

Add SimpleOverlayLocalizations.delegate to your app's localizationsDelegates to enable the overlay to pick up your app's locale. Override individual getters in a subclass to provide translations.

MaterialApp(
  localizationsDelegates: [
    SimpleOverlayLocalizations.delegate,
    GlobalMaterialLocalizations.delegate,
  ],
)

To provide translated strings, extend this class:

class MyLocalization extends SimpleOverlayLocalizations {
  @override
  String get title => AppLocalizations.of(context)!.loggerTitle;
}

Constructors

SimpleOverlayLocalizations()
const

Properties

copiedMessage String
no setter
copyTooltip String
no setter
exportTooltip String
no setter
hashCode int
The hash code for this object.
no setterinherited
labelLevel String
no setter
labelMessage String
no setter
labelRequestBody String
no setter
labelRequestHeaders String
no setter
labelResponseBody String
no setter
labelResponseHeaders String
no setter
labelTag String
no setter
labelTimestamp String
no setter
labelUrl String
no setter
logDetailTitle String
no setter
networkLogDetailTitle String
no setter
noLogsSubtitle String
no setter
noLogsTitle String
no setter
noNetworkSubtitle String
no setter
noNetworkTitle String
no setter
noResultsTitle String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String
no setter
sortNewest String
no setter
sortOldest String
no setter
title String
no setter

Methods

entriesCount(int count) String
logsTab(int count) String
networkTab(int count) String
noNetworkResultsSubtitle(String query) String
noResultsSubtitle(String query) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) SimpleOverlayLocalizations